Package: Basic4Cseq
Type: Package
Title: Basic4Cseq: an R/Bioconductor package for analyzing 4C-seq data
Version: 1.49.0
Date: 2025-06-27
Author: Carolin Walter
Maintainer: Carolin Walter <carolin.walter@uni-muenster.de>
Imports: methods, RCircos, BSgenome.Ecoli.NCBI.20080805
Depends: R (>= 3.5.0), Biostrings, GenomicAlignments, caTools,
        GenomicRanges, grDevices, graphics, stats, utils
Suggests: BSgenome.Hsapiens.UCSC.hg19
Description: Basic4Cseq is an R/Bioconductor package for basic
    filtering, analysis and subsequent visualization of 4C-seq
    data. Virtual fragment libraries can be created for any
    BSGenome package, and filter functions for both reads and
    fragments and basic quality controls are included. Fragment
    data in the vicinity of the experiment's viewpoint can be
    visualized as a coverage plot based on a running median
    approach and a multi-scale contact profile.
License: LGPL-3
biocViews: ImmunoOncology, Visualization, QualityControl, Sequencing,
        Coverage, Alignment, RNASeq, SequenceMatching, DataImport
git_url: https://git.bioconductor.org/packages/Basic4Cseq
git_branch: devel
git_last_commit: e0189bb
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 21:18:11 UTC; biocbuild
Built: R 4.6.0; ; 2026-05-19 04:42:48 UTC; unix
